rule bwa_mem:
    input:
        ref_file = rules.bwa_index.input.ref,
        ref_index_list = rules.bwa_index.output.list_index,
        fq1_file = f"{frangipane_obj.path_fastq}/{{sample_name}}_1.fastq.gz",
        fq2_file = f"{frangipane_obj.path_fastq}/{{sample_name}}_2.fastq.gz"
    output:
        bam_file = protected(f"{frangipane_obj.path_bam}/{{ref_name}}/{{sample_name}}-{{ref_name}}.bam"),
        bai_file = protected(f"{frangipane_obj.path_bam}/{{ref_name}}/{{sample_name}}-{{ref_name}}.bam.bai")
    log:
         error =  f"{frangipane_obj.path_logs}/bwa_mem/{{sample_name}}-{{ref_name}}.e",
         output = f"{frangipane_obj.path_logs}/bwa_mem/{{sample_name}}-{{ref_name}}.o"
    params:
        rg = f"@RG\\tID:{{sample_name}}\\tSM:{{sample_name}}\\tPL:Illumina",
        other_options_bwaMem = frangipane_obj.get_config_value("PARAMS","bwa_mem"),
        other_options_samtoolsSort = frangipane_obj.get_config_value("PARAMS","samtools_sort")
    threads: get_threads('bwa_mem', 2)
    message:
         f"""--------------------
-Running {{rule}}
|-- Input:
|   - Reference : {{input.ref_file}}
|   - Fastq R1 : {{input.fq1_file}}
|   - Fastq R2 : {{input.fq2_file}}
|-- Output:
|   - bam file: {{output}}
|-- Others infos :
|   - Threads : {{threads}}
|   - LOG output: {{log.output}}
|   - Other options bwa: {{params.other_options_bwaMem}}
|   - Other options samtools sort: {{params.other_options_samtoolsSort}}
--------------------
"""
    singularity:
        tools_config['SINGULARITY']['TOOLS']
    envmodules:
        tools_config["ENVMODULE"]["BWA"]
    shell:
        """
        cmd='bwa mem {params.other_options_bwaMem} -t {threads} {input.ref_file} {input.fq1_file} {input.fq2_file} -R '{params.rg}' |
        samtools sort {params.other_options_samtoolsSort} -@ {threads} -o {output.bam_file}' ; 
        echo $cmd > {log.output};

        (bwa mem {params.other_options_bwaMem} -t {threads} {input.ref_file} {input.fq1_file} {input.fq2_file} -R '{params.rg}' |
        samtools sort {params.other_options_samtoolsSort} -@ {threads} -o {output.bam_file}) 2> {log.error};
        
        cmd='samtools index -@ {threads} {output.bam_file}' ; 
        echo $cmd >> {log.output};

        ($cmd) 1>> {log.output} 2>> {log.error}"""