rule plot_mapping:
    input:
        csv = rules.merge_flagstat.output.stat_file,
    output: 
        png_mapping=f"{frangipane_obj.path_stat_plot}/mapping_read_ratio-{frangipane_obj.reference_basename}.png",
    log:
        output = f"{frangipane_obj.path_logs}/report/plot_mapping.o",
        error = f"{frangipane_obj.path_logs}/report/plot_mapping.e"
    message:
         f"""--------------------
-Running {{rule}}
|-- Input:
|    - Stat file : {{input.csv}}
|-- Output:
|    - Plot : {{output.png_mapping}}
|-- Other infos:
|    - LOG output : {{log.output}} 
--------------------
"""
    run:
        import pandas as pd
        import matplotlib.pyplot as plt
        import seaborn as sns

        df_bam_stat = pd.read_csv(input.csv,index_col=False,sep=",")
        df_bam_stat.sort_values(by=['sample'],inplace=True)

        plt.figure()  # figsize=(12, 5))
        ratio = sns.scatterplot(x='sample',y='value',hue='variable',data=pd.melt(df_bam_stat,'sample'))
        ratio.set(xlabel="sample",ylabel="ratio")
        ratio.set_title("Read mapped ratio ")
        plt.legend(bbox_to_anchor=(1.01, 1),borderaxespad=0);
        plt.savefig(output.png_mapping)
        plt.close()
